
***************
Semantic Router
***************

.. _semantic_router_api:


Semantic Router
===============

.. currentmodule:: redisvl.extensions.router

.. autoclass:: SemanticRouter
   :members:


Routing Config
==============

.. currentmodule:: redisvl.extensions.router

.. autoclass:: RoutingConfig
   :members:


Route
=====

.. currentmodule:: redisvl.extensions.router

.. autoclass:: Route
   :members:


Route Match
===========

.. currentmodule:: redisvl.extensions.router.schema

.. autoclass:: RouteMatch
   :members:


Distance Aggregation Method
===========================

.. currentmodule:: redisvl.extensions.router.schema

.. autoclass:: DistanceAggregationMethod
   :members:
